import React, { useState } from 'react';
import replaceHighlitingWord from '../utils/replaceHighlitingWord';
import { useEffect } from 'react';
import { IDictionary } from '../type';

interface IProps extends React.HTMLAttributes<HTMLDivElement> {
  dictionary: IDictionary[];
  isActivate?: boolean;
  children?: string | null;
}
function Highlighter({ dictionary, children = '', isActivate = false }: IProps) {
  const [clickedWord, setClickedWord] = useState('');
  const [pos, setPos] = useState({ x: 0, y: 0 });

  const onClickHandler = (event: React.MouseEvent<HTMLDivElement, MouseEvent>) => {
    const target = event.target as HTMLDivElement;
    event.stopPropagation();

    const { x, y } = calPos(event.clientX, event.clientY);
    setPos({
      x,
      y,
    });
    if (target.tagName === 'SPAN') {
      const nextWord = clickedWord === target.innerHTML ? '' : target.innerHTML;
      setClickedWord(nextWord);
    }
  };
  const calPos = (x: number, y: number) => {
    const newX =
      x > window.innerWidth - 400 ? window.innerWidth - 400 : Math.floor(x / 50) * 50 - 20;
    const newY = Math.floor(y / 50) * 55;

    return { x: newX, y: newY };
  };
  const closeDictionary = () => {
    setClickedWord('');
  };
  const innerHTML = isActivate
    ? replaceHighlitingWord({
        children,
        dictionary,
        clickedWord,
        pos,
      })
    : children;

  useEffect(() => {
    if (!document.querySelector('.close')) return;
    document.querySelector('.close')?.addEventListener('click', closeDictionary);
  }, [clickedWord]);

  return <div dangerouslySetInnerHTML={{ __html: innerHTML ?? '' }} onClick={onClickHandler} />;
}

export default Highlighter;
